<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author גיא שפר <guysoft@ort.org.il>
 * @author Denis Simakov <akinoame1@gmail.com>
 * @author Dotan Kamber <kamberd@yahoo.com>
 * @author Moshe Kaplan <mokplan@gmail.com>
 * @author Yaron Yogev <yaronyogev@gmail.com>
 * @author Yaron Shahrabani <sh.yaron@gmail.com>
 * @author Roy Zahor <roy.zahor@gmail.com>
 * @author alex <ralexay@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'rtl';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'עריכת דף זה';
$lang['btn_source']            = 'הצגת מקור הדף';
$lang['btn_show']              = 'הצגת דף';
$lang['btn_create']            = 'יצירת דף';
$lang['btn_search']            = 'חיפוש';
$lang['btn_save']              = 'שמירה';
$lang['btn_preview']           = 'תצוגה מקדימה';
$lang['btn_top']               = 'חזרה למעלה';
$lang['btn_newer']             = '<<  חדש יותר';
$lang['btn_older']             = 'פחות חדש  >>';
$lang['btn_revs']              = 'גרסאות קודמות';
$lang['btn_recent']            = 'שינויים אחרונים';
$lang['btn_upload']            = 'העלאה';
$lang['btn_cancel']            = 'ביטול';
$lang['btn_index']             = 'מפת האתר';
$lang['btn_secedit']           = 'עריכה';
$lang['btn_login']             = 'כניסה';
$lang['btn_logout']            = 'יציאה';
$lang['btn_admin']             = 'ניהול';
$lang['btn_update']            = 'עדכון';
$lang['btn_delete']            = 'מחיקה';
$lang['btn_back']              = 'חזרה';
$lang['btn_backlink']          = 'קישורים לכאן';
$lang['btn_backtomedia']       = 'חזרה לבחירת קובץ מדיה';
$lang['btn_subscribe']         = 'מעקב אחרי שינוים';
$lang['btn_profile']           = 'עדכון הפרופיל';
$lang['btn_reset']             = 'איפוס';
$lang['btn_resendpwd']         = 'הגדר סיסמה חדשה';
$lang['btn_draft']             = 'עריכת טיוטה';
$lang['btn_recover']           = 'שחזור טיוטה';
$lang['btn_draftdel']          = 'מחיקת טיוטה';
$lang['btn_revert']            = 'שחזור';
$lang['btn_register']          = 'הרשמה';
$lang['btn_media']             = 'מנהל המדיה';
$lang['loggedinas']            = 'נכנסת בשם';
$lang['user']                  = 'שם משתמש';
$lang['pass']                  = 'ססמה';
$lang['newpass']               = 'ססמה חדשה';
$lang['oldpass']               = 'אישור הססמה הנוכחית';
$lang['passchk']               = 'פעם נוספת';
$lang['remember']              = 'שמירת הפרטים שלי';
$lang['fullname']              = 'שם מלא';
$lang['email']                 = 'דוא״ל';
$lang['profile']               = 'פרופיל המשתמש';
$lang['badlogin']              = 'שם המשתמש או הססמה שגויים, עמך הסליחה';
$lang['badpassconfirm']        = 'מצטערים, הסיסמה שגויה';
$lang['minoredit']             = 'שינוים מזעריים';
$lang['draftdate']             = 'הטיוטה נשמרה אוטומטית ב־';
$lang['nosecedit']             = 'הדף השתנה בינתיים, הקטע שערכת אינו מעודכן - העמוד כולו נטען במקום זאת.';
$lang['regmissing']            = 'עליך למלא את כל השדות, עמך הסליחה.';
$lang['reguexists']            = 'משתמש בשם זה כבר נרשם, עמך הסליחה.';
$lang['regsuccess']            = 'ההרשמה הצליחה, המשתמש נרשם והודעה נשלחה בדוא״ל.';
$lang['regsuccess2']           = 'ההרשמה הצליחה, המשתמש נוצר.';
$lang['regmailfail']           = 'שליחת הודעת הדוא״ל כשלה, נא ליצור קשר עם מנהל האתר!';
$lang['regbadmail']            = 'יתכן כי כתובת הדוא״ל אינה תקפה, אם לא כך הדבר ליצור קשר עם מנהל האתר';
$lang['regbadpass']            = 'שתי הססמאות אינן זהות זו לזו, נא לנסות שוב.';
$lang['regpwmail']             = 'ססמת הדוקוויקי שלך';
$lang['reghere']               = 'עדיין אין לך חשבון? ההרשמה כאן';
$lang['profna']                = 'בוויקי הזה לא ניתן לשנות פרופיל';
$lang['profnochange']          = 'אין שינויים, הפרופיל לא עודכן';
$lang['profnoempty']           = 'השם וכתובת הדוא״ל לא יכולים להיות ריקים';
$lang['profchanged']           = 'הפרופיל עודכן בהצלחה';
$lang['profdeleteuser']        = 'הסר חשבון';
$lang['pwdforget']             = 'שכחת את הססמה שלך? ניתן לקבל חדשה';
$lang['resendna']              = 'הוויקי הזה אינו תומך בחידוש ססמה';
$lang['resendpwd']             = 'הגדר סיסמא חדשה בעבור';
$lang['resendpwdmissing']      = 'עליך למלא את כל השדות, עמך הסליחה.';
$lang['resendpwdnouser']       = 'משתמש בשם זה לא נמצא במסד הנתונים, עמך הסליחה.';
$lang['resendpwdbadauth']      = 'קוד אימות זה אינו תקף. יש לוודא כי נעשה שימוש בקישור האימות המלא, עמך הסליחה.';
$lang['resendpwdconfirm']      = 'נשלח קישור לאימות נשלח בדוא״ל.';
$lang['resendpwdsuccess']      = 'נשלחה ססמה חדשה בדוא״ל';
$lang['license']               = 'למעט מקרים בהם צוין אחרת, התוכן בוויקי זה זמין לפי הרישיון הבא:';
$lang['licenseok']             = 'נא לשים לב: עריכת דף זה מהווה הסכמה מצדך להצגת התוכן שהוספת בהתאם הרישיון הבא:';
$lang['searchmedia']           = 'חיפוש שם קובץ:';
$lang['searchmedia_in']        = 'חיפוש תחת %s';
$lang['txt_upload']            = 'בחירת קובץ להעלות';
$lang['txt_filename']          = 'העלאה בשם (נתון לבחירה)';
$lang['txt_overwrt']           = 'שכתוב על קובץ קיים';
$lang['lockedby']              = 'נעול על ידי';
$lang['lockexpire']            = 'הנעילה פגה';
$lang['js']['willexpire']      = 'הנעילה תחלוף עוד זמן קצר. \nלמניעת התנגשויות יש להשתמש בכפתור הרענון מטה כדי לאפס את מד משך הנעילה.';
$lang['js']['notsavedyet']     = 'שינויים שלא נשמרו ילכו לאיבוד.';
$lang['js']['searchmedia']     = 'חיפוש אחר קבצים';
$lang['js']['keepopen']        = 'השארת חלון פתוח על הבחירה';
$lang['js']['hidedetails']     = 'הסתרת פרטים';
$lang['js']['mediatitle']      = 'הגדרות הקישור';
$lang['js']['mediadisplay']    = 'סוג הקישור';
$lang['js']['mediaalign']      = 'יישור';
$lang['js']['mediasize']       = 'גודל התמונה';
$lang['js']['mediatarget']     = 'יעד הקישור';
$lang['js']['mediaclose']      = 'סגירה';
$lang['js']['mediainsert']     = 'הוספה';
$lang['js']['mediadisplayimg'] = 'הצגת התמונה.';
$lang['js']['mediadisplaylnk'] = 'הצגת הקישור בלבד.';
$lang['js']['mediasmall']      = 'גרסה קטנה';
$lang['js']['mediamedium']     = 'גרסה בינונית';
$lang['js']['medialarge']      = 'גרסה גדולה';
$lang['js']['mediaoriginal']   = 'הגרסה המקורית';
$lang['js']['medialnk']        = 'קישור לעמוד הפרטים';
$lang['js']['mediadirect']     = 'הקישור הישיר למקור';
$lang['js']['medianolnk']      = 'אין קישור';
$lang['js']['medianolink']     = 'אין לקשר לתמונה';
$lang['js']['medialeft']       = 'יישור התמונה לשמאל.';
$lang['js']['mediaright']      = 'יישור התמונה לימין.';
$lang['js']['mediacenter']     = 'מרכוז התמונה.';
$lang['js']['medianoalign']    = 'לא להשתמש ביישור.';
$lang['js']['nosmblinks']      = 'קישור לכונני שיתוף של Windows עובד רק באמצעות Microsoft Internet Explorer.
עדיין ניתן להעתיק ולהדביק את הקישור.';
$lang['js']['linkwiz']         = 'אשף הקישורים';
$lang['js']['linkto']          = 'קישור אל:';
$lang['js']['del_confirm']     = 'באמת למחוק?';
$lang['js']['restore_confirm'] = 'באמת לשחזר את הגירסא הזאת?';
$lang['js']['media_diff']      = 'הצגת הבדלים:';
$lang['js']['media_diff_both'] = 'זה לצד זה';
$lang['js']['media_select']    = 'בחר קבצים...';
$lang['js']['media_upload_btn'] = 'העלאה';
$lang['js']['media_done_btn']  = 'בוצע';
$lang['js']['media_drop']      = 'גרור לכאן קבצים בכדי להעלותם';
$lang['js']['media_cancel']    = 'הסר';
$lang['js']['media_overwrt']   = 'שכתב קבצים קיימים';
$lang['rssfailed']             = 'אירע כשל בעת קבלת הזנה זו:';
$lang['nothingfound']          = 'לא נמצאו תוצאות.';
$lang['mediaselect']           = 'קובצי מדיה';
$lang['fileupload']            = 'העלאת קובצי מדיה';
$lang['uploadsucc']            = 'ההעלאה הושלמה בהצלחה';
$lang['uploadfail']            = 'אירעה שגיאה בעת העלאת הקובץ. היתכן שתקלה זו נוצרה עקב הרשאות שגיות?';
$lang['uploadwrong']           = 'ההעלאה לא אושרה. קבצים בסיומת זו אסורים!';
$lang['uploadexist']           = 'הקובץ כבר קיים. הפעולה בוטלה.';
$lang['uploadbadcontent']      = 'התוכן שהועלה לא תאם את הסיומת %s של הקובץ.';
$lang['uploadspam']            = 'ההעלאה נחסמה על ידי רשימת חסימת הספאם.';
$lang['uploadxss']             = 'ההעלאה נחסמה בשל חשד לתוכן זדוני.';
$lang['uploadsize']            = 'הקובץ שהועלה היה גדול מדי. (%s לכל היותר)';
$lang['deletesucc']            = 'הקובץ %s נמחק.';
$lang['deletefail']            = 'לא ניתן למחוק את "%s" -- נא לבדוק את ההרשאות.';
$lang['mediainuse']            = 'הקובץ "%s" לא נמחק - הוא עדיין בשימוש.';
$lang['namespaces']            = 'שמות מתחם';
$lang['mediafiles']            = 'קבצים זמינים תחת';
$lang['accessdenied']          = 'אין לך הרשאה לצפות בדף זה.';
$lang['mediausage']            = 'יש להשתמש בתחביר הבא כדי להפנות לקובץ זה:';
$lang['mediaview']             = 'הצגת  הקובץ המקורי';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'כאן ניתן להעלות קובץ למרחב השם הנוכחי. ליצירת תת־מרחבי שם יש לצרף אותם לתחילת שם הקובץ, מופרדים בפסיקים, בשם הקובץ תחת "העלאה בתור".';
$lang['mediaextchange']        = 'סיומת הקובץ השתנתה מ־‎.%s ל־‎.%s!';
$lang['reference']             = 'הפניות אל';
$lang['ref_inuse']             = 'לא ניתן למחוק קובץ זה, כיוון שהדפים הבאים עדיין משתמשים בו:';
$lang['ref_hidden']            = 'חלק מההפניות נמצאות בדפים שאין לך הרשאות לקרוא אותם';
$lang['hits']                  = 'ביקורים';
$lang['quickhits']             = 'שמות דפים שנמצאו';
$lang['toc']                   = 'תוכן עניינים';
$lang['current']               = 'הגרסה הנוכחית';
$lang['yours']                 = 'הגרסה שלך';
$lang['diff']                  = 'הצגת שינוים מגרסה זו ועד הנוכחית';
$lang['diff2']                 = 'הצגת הבדלים בין הגרסאות שנבחרו';
$lang['difflink']              = 'קישור לתצוגה השוואה זו';
$lang['diff_type']             = 'הצגת הבדלים:';
$lang['diff_inline']           = 'באותה השורה';
$lang['diff_side']             = 'זה לצד זה';
$lang['line']                  = 'שורה';
$lang['breadcrumb']            = 'ביקורים אחרונים';
$lang['youarehere']            = 'זהו מיקומך';
$lang['lastmod']               = 'מועד השינוי האחרון';
$lang['by']                    = 'על ידי';
$lang['deleted']               = 'נמחק';
$lang['created']               = 'נוצר';
$lang['restored']              = 'שוחזר (%s)';
$lang['external_edit']         = 'עריכה חיצונית';
$lang['summary']               = 'תקציר העריכה';
$lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">תוסף פלאש לדפדפן</a> נדרש כדי להציג תוכן זה.';
$lang['download']              = 'הורדת מקטע';
$lang['tools']                 = 'כלים';
$lang['user_tools']            = 'כלים של משתמש';
$lang['site_tools']            = 'כלים של אתר';
$lang['page_tools']            = 'כלים של דף';
$lang['skip_to_content']       = 'עבור לתוכן';
$lang['mail_newpage']          = 'דף נוסף:';
$lang['mail_changed']          = 'דף שונה:';
$lang['mail_subscribe_list']   = 'דפים שהשתנו במרחב השם:';
$lang['mail_new_user']         = 'משתמש חדש:';
$lang['mail_upload']           = 'קובץ הועלה:';
$lang['pages_changes']         = 'דפים';
$lang['media_changes']         = 'קבצי מדיה';
$lang['qb_bold']               = 'טקסט מודגש';
$lang['qb_italic']             = 'טקסט נטוי';
$lang['qb_underl']             = 'טקסט עם קו תחתון';
$lang['qb_code']               = 'קוד';
$lang['qb_strike']             = 'טקסט מחוק';
$lang['qb_h1']                 = 'כותרת רמה 1';
$lang['qb_h2']                 = 'כותרת רמה 2';
$lang['qb_h3']                 = 'כותרת רמה 3';
$lang['qb_h4']                 = 'כותרת רמה 4';
$lang['qb_h5']                 = 'כותרת רמה 5';
$lang['qb_h']                  = 'כותרת';
$lang['qb_hs']                 = 'כותרת נבחרת';
$lang['qb_hplus']              = 'כותרת ברמה גבוהה יותר';
$lang['qb_hminus']             = 'כותרת ברמה נמוכה יותר';
$lang['qb_hequal']             = 'כותרת באותה רמה';
$lang['qb_link']               = 'קישור פנימי';
$lang['qb_extlink']            = 'קישור חיצוני';
$lang['qb_hr']                 = 'קו אופקי';
$lang['qb_ol']                 = 'איבר ברשימה ממוספרת';
$lang['qb_ul']                 = 'איבר ברשימה לא ממוספרת';
$lang['qb_media']              = 'תמונות וקבצים אחרים';
$lang['qb_sig']                = 'הוספת חתימה';
$lang['qb_smileys']            = 'חייכנים';
$lang['qb_chars']              = 'תווים מיוחדים';
$lang['upperns']               = 'מעבר למרחב השם שברמה שמעל הנוכחית';
$lang['admin_register']        = 'הוספת משתמש חדש';
$lang['metaedit']              = 'עריכת נתוני העל';
$lang['metasaveerr']           = 'אירע כשל בשמירת נתוני העל';
$lang['metasaveok']            = 'נתוני העל נשמרו';
$lang['img_backto']            = 'חזרה אל';
$lang['img_title']             = 'שם';
$lang['img_caption']           = 'כותרת';
$lang['img_date']              = 'תאריך';
$lang['img_fname']             = 'שם הקובץ';
$lang['img_fsize']             = 'גודל';
$lang['img_artist']            = 'צלם';
$lang['img_copyr']             = 'זכויות יוצרים';
$lang['img_format']            = 'מבנה';
$lang['img_camera']            = 'מצלמה';
$lang['img_keywords']          = 'מילות מפתח';
$lang['img_width']             = 'רוחב';
$lang['img_height']            = 'גובה';
$lang['subscr_subscribe_success'] = '%s נוסף לרשימת המינויים לדף %s';
$lang['subscr_subscribe_error'] = 'אירעה שגיאה בהוספת %s לרשימת המינויים לדף %s';
$lang['subscr_subscribe_noaddress'] = 'אין כתובת המשויכת עם הכניסה שלך, נא ניתן להוסיף אותך לרשימת המינויים';
$lang['subscr_unsubscribe_success'] = 'המשתמש %s הוסר מרשימת המינויים לדף %s';
$lang['subscr_unsubscribe_error'] = 'אירעה שגיאה בהסרת %s מרשימת המינויים לדף %s';
$lang['subscr_already_subscribed'] = 'המשתמש %s כבר מנוי לדף %s';
$lang['subscr_not_subscribed'] = 'המשתמש %s איננו רשום לדף %s';
$lang['subscr_m_not_subscribed'] = 'המשתמש שלך אינו רשום, נכון לעכשיו, לדף הנוכחי או למרחב השם.';
$lang['subscr_m_new_header']   = 'הוספת מינוי';
$lang['subscr_m_current_header'] = 'המינויים הנוכחיים';
$lang['subscr_m_unsubscribe']  = 'ביטול המינוי';
$lang['subscr_m_subscribe']    = 'מינוי';
$lang['subscr_m_receive']      = 'קבלת';
$lang['subscr_style_every']    = 'דוא״ל עם כל שינוי';
$lang['subscr_style_digest']   = 'הודעת דוא״ל המציגה את כל השינויים בכל עמוד (בכל %.2f ימים)';
$lang['subscr_style_list']     = 'רשימת השינויים בדפים מאז הודעת הדוא״ל האחרונה (בכל %.2f ימים)';
$lang['authtempfail']          = 'אימות משתמשים אינו זמין כרגע. אם מצב זה נמשך נא ליידע את מנהל הוויקי.';
$lang['i_chooselang']          = 'נא לבחור שפה';
$lang['i_installer']           = 'תכנית ההתקנה של DokuWiki';
$lang['i_wikiname']            = 'שם הוויקי';
$lang['i_enableacl']           = 'הפעלת ACL (מומלץ)';
$lang['i_superuser']           = 'משתמש־על';
$lang['i_problems']            = 'תכנית ההתקנה זיהתה מספר בעיות המפורטות להלן. אין באפשרותך להמשיך לפני תיקונן.';
$lang['i_modified']            = 'משיקולי אבטחה סקריפט זה יעבוד אך ורק עם התקנת DokuWiki חדשה שלא עברה כל שינוי.
                         עליך לחלץ שנית את הקבצים מהחבילה שהורדה או להיעזר בדף
                         <a href="http://dokuwiki.org/install">Dokuwiki installation instructions</a>';
$lang['i_funcna']              = 'פונקציית ה-PHP&rlm; <code>%s</code> אינה זמינה. יתכן כי מארח האתר חסם אותה מסיבה כלשהי?';
$lang['i_permfail']            = '<code>%s</code> אינה ניתנת לכתיבה על ידי DokuWiki. עליך לשנות הרשאות תיקייה זו!';
$lang['i_confexists']          = '<code>%s</code> כבר קיים';
$lang['i_writeerr']            = 'אין אפשרות ליצור את <code>%s</code>. נא לבדוק את הרשאות הקובץ/תיקייה וליצור את הקובץ ידנית.';
$lang['i_badhash']             = 'הקובץ Dokuwiki.php אינו מזוהה או שעבר שינויים (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - הערך אינו חוקי או ריק';
$lang['i_success']             = 'תהליך ההגדרה הסתיים בהצלחה. כעת ניתן למחוק את הקובץ install.php ולהמשיך אל ה־<a href="doku.php?id=wiki:welcome">DokuWiki החדש שלך</a>.';
$lang['i_failure']             = 'מספר שגיאות אירעו בעת כתיבת קובצי התצורה. יתכן כי יהיה צורך לתקנם ידנית לפני שניתן יהיה להשתמש ב־<a href="doku.php?id=wiki:welcome">DokuWiki החדש שלך</a>.';
$lang['i_policy']              = 'מדיניות ACL התחלתית';
$lang['i_pol0']                = 'ויקי פתוח (קריאה, כתיבה והעלאה לכולם)';
$lang['i_pol1']                = ' ויקי ציבורי (קריאה לכולם, כתיבה והעלאה למשתמשים רשומים)';
$lang['i_pol2']                = 'ויקי סגור (קריאה, כתיבה והעלאה למשתמשים רשומים בלבד)';
$lang['i_retry']               = 'ניסיון נוסף';
$lang['i_license']             = 'נא לבחור את הרישיון שיחול על התוכן שבוויקי שלך:';
$lang['recent_global']         = 'נכון לעכשיו מתנהל על ידיך מעקב אחר מרחב השם <b>%s</b>. כמו כן, באפשרותך <a href="%s">לצפות בשינויים האחרונים בוויקי כולו</a>.';
$lang['years']                 = 'לפני %d שנים';
$lang['months']                = 'לפני %d חודשים';
$lang['weeks']                 = 'לפני %d שבועות';
$lang['days']                  = 'לפני %d ימים';
$lang['hours']                 = 'לפני %d שעות';
$lang['minutes']               = 'לפני %d דקות';
$lang['seconds']               = 'לפני %d שניות';
$lang['wordblock']             = 'השינויים שלך לא נשמרו כיוון שהם מכילים טקסט חסום (ספאם).';
$lang['media_searchtab']       = 'חיפוש';
$lang['media_file']            = 'קובץ';
$lang['media_viewtab']         = 'תצוגה';
$lang['media_edittab']         = 'עריכה';
$lang['media_historytab']      = 'היסטוריה';
$lang['media_list_rows']       = 'שורות';
$lang['media_sort_name']       = 'שם';
$lang['media_sort_date']       = 'תאריך';
$lang['media_namespaces']      = 'בחר מרחב שמות';
